#
# spec file for package libzfcphbaapi0
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libzfcphbaapi0
VCS: https://src.suse.de/SLFO-pool/libzfcphbaapi0#09f0256bd4f3692d52ea945be1ab2ddded487158e56bcba31066a45227811643
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libHBAAPI2-devel
BuildRequires:  libsgutils-devel
BuildRequires:  libtool
BuildRequires:  linux-glibc-devel
BuildRequires:  sysfsutils
Url:            https://github.com/ibm-s390-linux/libzfcphbaapi
Summary:        zfcp HBA API library
License:        EPL-1.0
Group:          System/Libraries
Version:        3.0.2
Release:        160000.2.1
Source:         libzfcphbaapi-%{version}.tar.gz
Patch1:         fix-build-errors.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  s390 s390x
%define _zfcp_hbaapi libzfcphbaapi-%{version}

%description
The zfcp device driver is a FCP device driver for Linux for zSeries.
The whole implementation of FC-HBA for the zfcp device driver is called
zfcp HBA API. It is a shared library which provides the API defined in
FC-HBA.

Authors:
--------
    Sven Schuetz <sven@de.ibm.com> (active maintainer)
    Andreas Herrmann <aherrman@de.ibm.com>
    Stefan Voelkel <Stefan.Voelkel@millenux.com>

%prep
if file /bin/bash | grep 32-bit.*390 && [ `arch` != s390 ]; then exit 1;fi
%autosetup -p1 -n %{_zfcp_hbaapi}
chmod a-x README ChangeLog
autoreconf -iv

%build
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=%{_prefix} --libdir=%{_libdir} --mandir=%{_mandir} --enable-vendor-lib --disable-static
make CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"

%install
make DESTDIR=$RPM_BUILD_ROOT install

# Get rid of a couple unnecessary files
rm -f $RPM_BUILD_ROOT/%{_libdir}/libzfcphbaapi.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/libzfcphbaapi.so

# Get rid of some "doc" files that are already in /usr/share/packages/doc
rm -f $RPM_BUILD_ROOT/usr/share/zfcp-hbaapi-2.1.1/README
rm -f $RPM_BUILD_ROOT/usr/share/zfcp-hbaapi-2.1.1/COPYING

%post
ldconfig
ORG=com.ibm.libzfcphbaapi
LIB=%{_libdir}/libzfcphbaapi.so.0
STR="$ORG       $LIB"
CONF=/etc/hba.conf
if test -f $CONF; then
    ORIG=$(sed -n "s/^[[:space:]]*$ORG[[:space:]]*\(.*\)/\1/p" $CONF)
    if [ "$ORIG" != "$LIB" ] ; then
        echo $STR >> $CONF
    else
        echo "** $CONF already configured"
        echo "** system configuration not updated"
    fi;
else
    echo "** WARNING: $CONF does not exist"
    echo "** system configuration not updated"
fi

%postun
ldconfig
CONF=/etc/hba.conf
ORG=com.ibm.libzfcphbaapi

if [ "${1}" = "0" ]; then	# Keep the entry for an upgrade, remove it for an uninstall
  if test -f $CONF; then
    sed -i -e "/^$ORG /d" $CONF
  fi
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_bindir}/zfcp_*
%{_libdir}/libzfcphbaapi.so.0*
%doc README ChangeLog COPYING
%doc %{_mandir}/man3/*.3.gz
%doc %{_mandir}/man8/*.8.gz
%dir /usr/share/zfcp-hbaapi-%{version}
/usr/share/zfcp-hbaapi-%{version}/*

%changelog
* Mon May  5 2025 nikolay.gueorguiev@suse.com
- Updated the .spec file (bsc#1242420)
- Updated the patch (bsc#1234472)
  * fix-build-errors.patch
* Fri Dec 13 2024 nikolay.gueorguiev@suse.com
- Update libzfcphbaapi0 to 3.0.2 (jsc#PED-11492)
  * Version 3.0.2 contains small updates for building:
    zfcp-hbaapi,zfcp_ping: fix -Wimplicit-function-declaration
- Updated patch fix-build-errors.patch
* Mon Dec  2 2024 nikolay.gueorguiev@suse.com
- Upgrade libzfcphbaapi0 to 3.0.1 (jsc#PED-11492)
  * ** Version 3.0.1 contains small updates for building:
  * README: reflect that the code default for vendorlib build is "no"
  * Makefile.am: fix dependency on libzfcphbaapi.la for zfcp_ping & zfcp_show
  * Makefile.am: add subdir-objects for fc_tools/
  * configure.in: remove AC_HEADER_STDC , replace AC_LANG_C with AC_LANG([C])
  * ** v3.0.0
  * Version 3.0.0 re-licenses lib-zfcp-hbaapi to EPL-1.0.
  * Source code is the same as the previously released v2.2.0.
* Wed Feb  6 2019 hare@suse.de
- Update to zfcp-hbaapi-2.2.0 (bsc#1094884)
  - Fix build for PowerPC
  - add port speed capabilities as defined in FC-GS-7
* Fri Nov  6 2015 mpost@suse.com
- Modified the %%postun scriptlet to only remove the entry from
  /etc/hba.conf when an RPM remove/uninstall is being done, not
  when an upgrade is being performed. (bsc#953775)
* Wed Sep 16 2015 mpost@suse.com
- Changed BuildRequires sg3_utils-devel to libsgutils-devel,
  since that is the new name for it.
- Removed a couple of files that were duplicates between
  /usr/share/packages/doc and /usr/share/zfcp-hbaapi-2.1.1
- Changed several hardcoded paths in the spec file to use
  %%{_variables} instead.
- Made the following changes at the request of IBM (bsc#868684):
  - Dropped the -devel subpackage and moved the contents back
    into the main package.
  - Add --disable-static to prevent the libzfcphbaapi.a library
    from building.
  - Removed the /usr/lib64/libzfcphbaapi.so symbolic link
  - At uninstall time, remove the relevant entry from /etc/hba.conf
- Added an rpmlintrc file to suppress a couple of warnings that are
  never going to be resolved.
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Tue Feb 25 2014 jjolly@suse.com
- Added COPYING for licensing purposes (bnc#854513)
* Fri Feb  7 2014 jjolly@suse.com
- Added /etc/hba.conf registration for the post install script
  (FATE#316146)
* Fri Jan 24 2014 jjolly@suse.com
- Enabled vendor library (FATE#316146)
* Fri Jan 24 2014 jjolly@suse.com
- Updated to libzfcphbaapi 2.1.1
  - Added linux-glibc-devel autoconf automake and libtool to
    BuildRequires
  - Removed outdated linux kernel headers
  - Removed three outdated patches
  - Fixed license strings to CPL-1.0
  - Changed devel library to Development/Libraries group
  - Making with -fno-strict-aliasing
* Wed Apr 17 2013 mpost@suse.com
- libzfcphbaapi: correctly convert WWN and LUN strings to u64 (bnc#814845)
  - zfcp-hbaapi: correctly convert WWN and LUN strings to u64 with
    s390-sles11sp3-zfcp-hbaapi-parse-u64-as-ull.patch
* Fri Mar 22 2013 mpost@suse.com
- libzfcphbaapi: find sg dev without deprecated sysfs (bnc#810453)
  - zfcp-hbaapi: find sg dev without deprecated sysfs
* Tue Feb 26 2013 uli@suse.com
- Fix crash on HBA_FreeLibrary call. (bnc#803556)
* Wed Jan 16 2013 uli@suse.com
- update to 2.1 (FCP pass-through support, event support;
  fate#314086)
* Fri Aug  5 2011 hare@suse.de
- Reference libsgutils2 (bnc#709565)
* Fri Nov 21 2008 jjolly@suse.de
- Updated to 2.0-v2 of the package with the following changes:
  - needed to accomodate upstream sysfs layout changes
  - fixed one bug
  - some cleanup in the license headers (updated URLs etc)
  - cleanup in the Makefile concerning the doxygen documentation
- Added doxygen dependency
- Included extra manpages
- Added /usr/share/zfcp-hbaapi-2.0 to the devel package
- Added libzfcphbaapi.so to the devel package
* Tue Sep  2 2008 jjolly@suse.de
- Initial package creation
